import sys
if sys.version_info < (3, 5):
    from .aiolifx34 import LifxDiscovery
else:
    from .aiolifx import LifxDiscovery
from .message import *
from .msgtypes import *
from .unpack import unpack_lifx_message



product_map = {1: "Original 1000",
                3: "Color 650",
                10: "White 800 (Low Voltage)",
                11: "White 800 (High Voltage)",
                18: "White 900 BR30 (Low Voltage)",
                20: "Color 1000 BR30",
                22: "Color 1000",
                27: "LIFX A19",
                28: "LIFX BR30",
                29: "LIFX+ A19",
                30: "LIFX+ BR30",
                31: "LIFX Z"
}

features_map = {1: {"color": True,
                    "infrared": False,
                    "multizone": False},
                3: {"color": True,
					"infrared": False,
					"multizone": False},
                10: {"color": False,
					"infrared": False,
					"multizone": False},
                11: {"color": False,
					"infrared": False,
					"multizone": False},
                18: {"color": False,
					"infrared": False,
					"multizone": False},
                20: {"color": True,
					"infrared": False,
					"multizone": False},
                22: {"color": True,
					"infrared": False,
					"multizone": False},
                27: {"color": True,
					"infrared": False,
					"multizone": False},
                28: {"color": True,
					"infrared": False,
					"multizone": False},
                29: {"color": True,
					"infrared": True,
					"multizone": False},
                30: {"color": True,
					"infrared": True,
					"multizone": False},
                31: {"color": True,
					"infrared": False,
					"multizone": True}
}
